aboutsummaryrefslogtreecommitdiffstats
path: root/lib/observer/src/crashdump_viewer.erl
diff options
context:
space:
mode:
authorSiri Hansen <[email protected]>2013-12-17 11:11:17 +0100
committerDan Gudmundsson <[email protected]>2014-01-27 16:13:57 +0100
commit9da4c7b4e41c325569d2576fa4c55568a1f1cfa2 (patch)
treee145ca0d6bfb014c4ebfdc37d0383f384df926f2 /lib/observer/src/crashdump_viewer.erl
parent2694299fe15c0553101d2107f6689975d16525dc (diff)
downloadotp-9da4c7b4e41c325569d2576fa4c55568a1f1cfa2.tar.gz
otp-9da4c7b4e41c325569d2576fa4c55568a1f1cfa2.tar.bz2
otp-9da4c7b4e41c325569d2576fa4c55568a1f1cfa2.zip
observer: renamed crashdump_viewer files and fixed makefiles
Diffstat (limited to 'lib/observer/src/crashdump_viewer.erl')
-rw-r--r--lib/observer/src/crashdump_viewer.erl10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/observer/src/crashdump_viewer.erl b/lib/observer/src/crashdump_viewer.erl
index 53e0241711..a17efbccb0 100644
--- a/lib/observer/src/crashdump_viewer.erl
+++ b/lib/observer/src/crashdump_viewer.erl
@@ -153,7 +153,7 @@ stop_debug() ->
start() ->
start(undefined).
start(File) ->
- crashdump_viewer_wx:start(File).
+ cdv_wx:start(File).
stop() ->
case whereis(?SERVER) of
@@ -216,7 +216,7 @@ usage() ->
%% External functions
%%====================================================================
%%%--------------------------------------------------------------------
%%% Start the server - called by crashdump_viewer_wx
start_link() ->
case whereis(?SERVER) of
undefined ->
@@ -226,7 +226,7 @@ start_link() ->
end.
%%%-----------------------------------------------------------------
-%%% Called by crashdump_viewer_wx
+%%% Called by cdv_wx
read_file(File) ->
cast({read_file,File}).
@@ -1378,7 +1378,7 @@ get_ports(File) ->
lookup_and_parse_index(File,?port,ParseFun,"ports").
%% Converting port string to tuple to secure correct sorting. This is
-%% converted back in cdv_port_wx:format/1.
+%% converted back in cdv_port_cb:format/1.
port_to_tuple("#Port<"++Port) ->
[I1,I2] = string:tokens(Port,".>"),
{list_to_integer(I1),list_to_integer(I2)}.
@@ -1790,7 +1790,7 @@ get_atoms1(Fd,[Bin|Bins],N,Atoms) ->
%% This ensures sorting according to first actual letter in the atom,
%% disregarding possible single quote. It is formatted back to correct
-%% syntax in cdv_atom_wx:format/1
+%% syntax in cdv_atom_cb:format/1
get_atom(<<"\'",Atom/binary>>) ->
{Atom,q}; % quoted
get_atom(Atom) when is_binary(Atom) ->
@@ -216,7 +216,7 @@ usage() ->
%%====================================================================
%%%--------------------------------------------------------------------
-%%% Start the server - called by crashdump_viewer_wx
+%%% Start the server - called by cdv_wx
start_link() ->
case whereis(?SERVER) of